<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Visualizador de imaxes</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>Imaxe</translation>
    </message>
    <message>
        <source>images</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>album</source>
        <translation>álbum</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>álbums</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Xestionar sincronización</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizando:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Sen nome</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Importadas recentemente</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favoritas</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Tes a certeza de querer eliminar este álbum?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Liña temporal</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Engadir</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Podes engadir un cartafol de sincronización ou arrastrar e soltar imaxes na liña temporal</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Sen nome</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Visualizador de imaxes</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imaxes</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Tes a certeza de querer engadir as imaxes a este álbum?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sincronizar e crear</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Está seguro de engadir á lista de sincronización e crear o album co nome deste cartafol?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Exportada correctamente</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Fallou a exportación</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Tes a certeza de querer enviar as imaxes ao lixo?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Este ficheiro contén varias páxinas, por favor emprega o Evince para velas todas.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar no portarretallos</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar do álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotar á dereita</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotar á esquerda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Engadir</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Podes engadir un cartafol de sincronización ou arrastrar e soltar imaxes na liña temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Engadir ao álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Engadir a un novo álbum</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Abrir cartafol</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Non tes permiso para ver a imaxe</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Data da foto</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data da modificación</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño do ficheiro</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espazo de cor</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distancia focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Máxima apertura</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de brancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de cámara</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Non escalar</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Axustar páxina á imaxe</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Axustar imaxe á páxina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escalar a:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetros</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetros</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Polgadas</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posición da imaxe</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escalando</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Axustes da imaxe</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Persiás</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Conmutador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Escorregadizo</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Anel</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Seleccionar cartafol</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Este directorio non está dispoñible para sincronizar</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Engadir cartafol</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Xestor de sincronización</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>A lista de directorio está baleira</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancelar sincronización</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>O dispositivo foi removido</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>O directorio xa non existe</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculando...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Vendo imaxe</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Rematar a presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar do álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotar á dereita</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotar á esquerda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Pantalla anterior</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Pantalla seguinte</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Por favor insire un novo atallo</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Atallos</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Ver imaxe</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Reestablecer por defecto</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Rematar a presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar do álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotar á dereita</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotar á esquerda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Rematar a presentación</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Por en pausa/Reproducir</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Configuración da diapositiva</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Cambiar efecto</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Cambiar duración</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segundo</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Xestión da imaxe</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamaño 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Encaixar á xanela</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotar á esquerda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotar á dereita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Non se atoparon ficheiros de imaxe</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 imaxe</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 imaxes</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Xestionar sincronización</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizando:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Engadir</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Podes engadir un cartafol de sincronización ou arrastrar e soltar imaxes na liña temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Engadir ao álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Engadir a un novo álbum</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar no portarretallos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotar á dereita</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotar á esquerda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Configuración da diapositiva</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efecto</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atallos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM aaaa</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Importadas recentemente</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuracións</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>O visualizador de imaxes é un xestor de imaxes moderno e fluído.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Ten como características a xestión, visualización e a edición básica de imaxes.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema escuro</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Liña temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Engadir ao álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Engadir a un novo álbum</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Saír de pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar no portarretallos</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar do álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Poñer nas favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar das favoritas</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Amosar xanela de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ocultar xanela de navegación</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotar á dereita</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotar á esquerda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información da imaxe</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>